/*************************************************************************/
/*************************************************************************/
/* H. Timucin OZDEMIR                                                    */
/* Date : February, 1997                                                 */
/* File Name : FuzzySet.h                                                */
/*************************************************************************/
/*
    index=0 means that myMF does not refer to a MembershipVector and 
    myValues vector is not in use. As a result our fuzzy set is some 
    kind of continuous function.

    It always allocates a new area for its member variables therefore
    these areas should be deallocated in the destructor.

*/
/*************************************************************************/

#ifndef _FUZZYSET_H
#define _FUZZYSET_H

#include <iostream.h>
#include "Vector.h"
#include "MembershipFunction.h"
#include "MembershipVector.h"
#include "Function.h"

class FuzzySet 
{
   public:

     float getMFValue(int a);
     float getMFValue(float a);
     void setMFunction(MembershipFunction *);
     FuzzySet *cutOffCopy(float);
     Function *cutOffCopyMF(float);

     //* Constructors

     FuzzySet();
     FuzzySet(MembershipFunction *);
     FuzzySet(Vector);
     FuzzySet(Vector *, MembershipVector *);

     //* Destructor

     ~FuzzySet();

     //* Operator Overloading

     FuzzySet operator=(const FuzzySet &);

     friend ostream& operator<<(ostream&,const FuzzySet &);

   private:

     MembershipFunction *myMF;
                 Vector *myValues;
                    int index;

}; // end of class FuzzySet

#endif
